# Powered By Odin's Spear

A collection of community-built automations designed to address real-world challenges using Odin's Spear. While these automations are not officially part of the core solution, they serve as practical examples for various use cases. As with all code shared in this documentation, you can copy them into your IDE, customize them to suit your environment, and put them to use.

<figure><img src=".gitbook/assets/powered-by-os.svg" alt="Powered By Odin's Spear"><figcaption></figcaption></figure>